###Chukchi Sea CWMRDA and FDis
getwd()
setwd("/Users/laurensutton/Desktop")
library(FD)
library(ggplot2)
library(ade4)
library(vegan)
library(MuMIn)
library(nlme)
library(ggpubr)
library(corrplot)
library(reshape2)
library(visreg)
library(grid)
library(car)
library(ggsn)
library(forcats)
####################################################################################################
#RLQ, 4th corner, RLQ-4th corner analysis 
##Chukchi
##Traits Matrix (Q)
ChukchiQ<-read.csv("Fims.3 2/ChukchiSeaTaxonByTrait080621.csv", 
                  row.names = 1) ##read in taxa by trait file
head(ChukchiQ)
ChukchiQfuzzy<-as.data.frame(prep.fuzzy(ChukchiQ, c(5,5,5,3,3,6,4,4,3))) ##standardize modalities to a maximum of 1 within a trait
ChukchiQfuzzy[is.na(ChukchiQfuzzy)] <- 0 ## make NAs = 0
View(ChukchiQfuzzy)
corChukchiTraits<-cor(ChukchiQfuzzy)
ChukchiCorPlotTraits<-corrplot(corChukchiTraits, method="number", order = "original", 
                               addCoef.col = "grey", diag = FALSE, is.corr = TRUE,
                               type="lower",tl.col = "black")##See Figure in Supplement

##Biomass Matrix (L)
ChukchiL<-read.csv("Fims.3 2/ChukchiSeaStationByTaxon080621.csv",row.names = 1) ##taxa by station file
dim(ChukchiL) ##246 taxa
ChukchiLtrans<-ChukchiL^(1/4)##transform biomass matrix
ChukchiL2<-read.csv("Fims.3 2/ChukchiSeaStationByTaxon080621.csv") ##taxa by station file with stations as first row
Cbiomass<-cbind(melt(ChukchiLtrans), c(rep(ChukchiL2$X,246)))
names(Cbiomass)<-c("species", "biomass", "station")
summary(Cbiomass)
ggplot()+
  geom_tile(data=Cbiomass, aes(x=station, y=species, fill=biomass))+
  scale_fill_gradient(low = "white", high = "black") ##shade plot for biomass; 4th root transformation seems appropriate
##Environment matrix (R)
ChukchiR<-read.csv("Fims.3 2/ChukchiEnv.csv", row.names = 1) ##import environmental data
ChukchiRstand<-as.data.frame(cbind(scale(ChukchiR[,c(1:7)]), ChukchiR[,c(8,9)])) ##standardized environmental data centered on zero
head(ChukchiRstand)
CorChukchiEnv<-cor(ChukchiRstand)
ChukchiCorPlot<-corrplot(CorChukchiEnv, method="number", order = "original", 
                         addCoef.col = "black", diag = FALSE, is.corr = TRUE,
                         type="lower",tl.col = "black", shade.col = "grey50",
                         col=colorRampPalette(c("blue","grey70","red"))(200))##See Figure in Supplement
##Sand/Mud correlated (=-0.8); remove for analyses
##Salinity/Temp correlated(=-0.75); remove for analyses
#Investigating which traits are driving functional composition
##Chukchi
#fourthcorner analysis
##To see if bivariate relationships exist between 
##modalities and environmental variables 
##Chukchi: used gravel, mud, depth, temperature,salinity, chl.a 
##removed sand due to high correlation
head(ChukchiRstand)
fourthC<-fourthcorner(ChukchiRstand[,c(1,3:5,7)],
                      ChukchiLtrans,
                      ChukchiQfuzzy, nrepet = 4999, ##can also use less permutations if too slow
                      p.adjust.method.G = 'fdr', 
                      p.adjust.method.D = 'fdr',
                      modeltype = 6) ##use false discovery rate to account for multiple permutations
plot(fourthC, alpha=0.05) ##multiple modalities have bivariate relationships with environmental variables; 

##make dataframe for ggplot representation
modsrep<-as.data.frame(c(rep("BF1", 5),rep("BF2", 5),rep("BF3",5),  rep("BF4",5),rep("BF5",5),
                         rep("BS1",5),rep("BS2",5),rep("BS3",5),rep("BS4",5),rep("BS5",5),
                         rep("FH1",5), rep("FH2",5), rep("FH3",5), rep("FH4",5), rep("FH5",5),
                         rep("F1",5), rep("F2",5), rep("F3",5),
                         rep("LD1",5), rep("LD2",5), rep("LD3",5),
                         rep("LH1",5), rep("LH2",5), rep("LH3",5), rep("LH4",5), rep("LH5",5), rep("LH6",5),
                         rep("MV1",5), rep("MV2",5), rep("MV3",5), rep("MV4",5),
                         rep("R1", 5), rep("R2", 5), rep("R3", 5), rep("R4",5),
                         rep("SO1",5), rep("SO2",5), rep("SO3",5)))
fourth.corner.C<-as.data.frame(cbind(as.data.frame(fourthC$tabD2$obs), 
                                     as.data.frame(fourthC$tabD2$names),
                                     as.data.frame(fourthC$tabD2$adj.pvalue),
                                     as.data.frame(modsrep),
                                     as.data.frame(rep(c("Gravel","Mud",
                                                         "Depth", "Temp", "Chl.a"),38))))
names(fourth.corner.C)<-c("Pearson","Relation", "adj.pvalue","Modality", "Env.Var")
View(fourth.corner.C)
summary(fourth.corner.C)
bl2<-colorRampPalette(c("navy","royalblue","lightskyblue"))(200) 
re <- colorRampPalette(c("mistyrose", "red2","darkred"))(200)
##only show Pearson values for pvalues < 0.05
Chukchi.four.corner.sig<-as.data.frame(subset(fourth.corner.C, adj.pvalue < 0.05))
Chukchi.four.corner.notsig<-as.data.frame(subset(fourth.corner.C, adj.pvalue > 0.05))
fourth.corner.chukchi.plot<-ggplot( )+
  geom_tile(data=Chukchi.four.corner.sig, 
            aes(x=Env.Var, y=fct_rev(Modality),fill=Pearson))+  
  scale_fill_gradient2(low=bl2, mid="grey50", high = re,midpoint=0.0, limits = c(-.26,.26))+
  geom_text(data=Chukchi.four.corner.sig,
            aes(x=Env.Var, y=fct_rev(Modality), label=round(Pearson,2)),color="white")+
  theme_classic()+
  theme(axis.text = element_text(color="black", size=12),
        axis.title = element_text(color="black", size=14))+
  geom_tile(data=Chukchi.four.corner.notsig, 
            aes(x=Env.Var, y=fct_rev(Modality)), fill="grey50", color="black")+
  scale_y_discrete(limits = rev(unique(sort(Chukchi.four.corner.sig$Modality))))+
  scale_y_discrete(limits = rev(unique(sort(Chukchi.four.corner.notsig$Modality))))+
  xlab("")+
  ylab("Modality")
  

fourth.corner.chukchi.plot

##RLQ analysis
##Chukchi: used gravel, mud, depth, temperature, chl.a 
##removed sand and salinity due to high correlation
dudiL <- dudi.coa (ChukchiLtrans, scannf = FALSE) ##biomass
dudiR <- dudi.pca (ChukchiRstand[,c(1,3:5,7)], scannf = FALSE, nf = 2,row.w = dudiL$lw)##env
dudiQ <- dudi.pca (ChukchiQfuzzy, scannf = FALSE, row.w = dudiL$cw)##traits

##supplemental ordinations for Chukchi
biplot(dudiL) ##CA
biplot(dudiR) ##PCA
biplot(dudiQ) ##PCA

##RLQ
vlt.rlq <- rlq (dudiR = dudiR, dudiL = dudiL, dudiQ = dudiQ, scannf = FALSE)
randtest(vlt.rlq, nrepet = 4999) ##model 2 and 4 are significant (p<0.05)
plot(randtest(vlt.rlq)) ##model 2 and 4 are significant
summary(vlt.rlq) ##for Table 2; RLQ output; total inertia: 1.486; Eig.values:1.357, 0.068, 0.033, 0.021, 0.006
##Proj. inertia: 91%, 5%; 
 
##global significance test using the fourthcorner2 function (this should mirror the randtest() function for RLQ above)
Crlq<-fourthcorner2(ChukchiRstand[,c(1,3:5,7)],ChukchiLtrans, ChukchiQfuzzy,
                    modeltype = 6, p.adjust.method.G = "fdr", nrepet=4999) 
summary(Crlq) ##Chukchi is globally significant

##environmental variables vs. Q-axes
##r-axes
four4c<-fourthcorner.rlq(vlt.rlq, modeltype=6,
                        p.adjust.method.G = "fdr",
                        p.adjust.method.D = "fdr",
                        typetest = "R.axes") ##test environmental variables against modality gradient
plot(four4c, alpha=.05, stat="D2", type="biplot") #show environmental variables that have significant (p<0.05) relationships
##highlight signficant environmental variables in RLQ
##plot Beaufort rlq.env.matrix
Chukchi.rlq.mods<-as.data.frame(vlt.rlq$c1)
Chukchi.rlq.sites<-as.data.frame(vlt.rlq$lR)
plot(vlt.rlq)
##plot via ggplot
Chukchi.rlq.env<-as.data.frame(cbind((vlt.rlq$li),c("Gravel", "Mud", "Depth",
                                                    "Temperature",  "Chl.a")))
names(Chukchi.rlq.env)[3]<-"Env"
head(Chukchi.rlq.env)
##ggplot RLQ with RLQ-4th corner env. variables highlighted
##depth did not have a relationship with the RLQ trait axes
C.rlq.env.plot<-ggplot()+
  geom_hline(yintercept = 0, linetype = 2) +
  geom_vline(xintercept = 0, linetype = 2)+
  geom_segment(data=Chukchi.rlq.env[c(1,2,4,5),], aes(x=0, xend=Axis1, y=0, yend=Axis2),
               alpha=1, size=.4, color="black",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_segment(data=Chukchi.rlq.env[c(3),], aes(x=0, xend=Axis1, y=0, yend=Axis2),
               alpha=1, size=.4, color="grey50",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_label(data=Chukchi.rlq.env[c(1,2,4,5),], aes(x=Axis1, y=Axis2,
                                       label=Env),color="black", size=5)+
  geom_label(data=Chukchi.rlq.env[c(3),], aes(x=Axis1, y=Axis2,
                                                           label=Env),color="grey50",size=5)+
  theme_bw()+
  theme(axis.title = element_text(size=18))+
  xlim(-1, 1)+
  ylim(-.25, .25)+
  xlab("Projected inertia (91%): Axis 1")+
  ylab("Projected inertia (5%): Axis 2")+
  labs(color='Pearson') 
C.rlq.env.plot 

##modalities vs. environmental axes:
##q-axes
four2<-fourthcorner.rlq(vlt.rlq, modeltype=6,
                        p.adjust.method.G = "fdr",
                        p.adjust.method.D = "fdr",
                        typetest = "Q.axes") ##test modalities against environmental gradient
plot(four2, alpha=0.05, stat="D2") 
plot(four2, alpha=.05, stat="D2", type="biplot") #show modalities that have significant (p<0.05) relationships
##BS, FH, LH, MV, all have multiple associations

##plot the relationship of significant modalities along the RLQ axes
modsAbr<-c("BF1","BF2", "BF3","BF4", "BF5",
           "BS1", "BS2", "BS3", "BS4", "BS5",
           "FH1", "FH2", "FH3", "FH4", "FH5",
           "F1", "F2",  "F3",
           "LD1", "LD2","LD3", 
           "LH1", "LH2", "LH3","LH4", "LH5","LH6",
            "MV1", "MV2", "MV3", "MV4",
           "R1", "R2", "R3","R4",
           
           "SO1", "SO2", "SO3")
Traits<-c(rep("Body form", 5), rep("Body size", 5),
          rep("Feeding habit", 5),
          rep("Fragility",3), rep("Larval development",3),
          rep("Living habit", 6), rep("Movement",4),
          rep("Reproductive strategy", 4), 
          rep("Sociability", 3))
##make data frames for significant and non-significant modalities
##using 4thcorner-RLQ test for "Q-axes"
four2Coutput<-as.data.frame(cbind(as.data.frame(four2$tabD2$obs), 
                                  as.data.frame(four2$tabD2$names),
                                  as.data.frame(four2$tabD2$adj.pvalue)))
names(four2Coutput)<-c("Pearson","Relation", "adj.pvalue")
summary(four2Coutput)
View(four2Coutput)
##make 2 data frames: for modality relationship with each axis
four2CSubsetaxis1 <- as.data.frame(four2Coutput[grep("AxcR1", four2Coutput$Relation), ])
summary(four2CSubsetaxis1)
names(four2CSubsetaxis1)<-c("PearsonAxis1", "RelationAxis1", "adj.pvalueAxis1")
four2CSubsetaxis2<-as.data.frame(four2Coutput[grep("AxcR2", four2Coutput$Relation), ])
summary(four2CSubsetaxis2)
names(four2CSubsetaxis2)<-c("PearsonAxis2", "RelationAxis2", "adj.pvalueAxis2")

##use location of modalities along RLQ axes
Chukchi.rlq.mods<-as.data.frame(vlt.rlq$c1)
four2CstatDoutput<-as.data.frame(cbind(four2CSubsetaxis1[,c(1,3)],four2CSubsetaxis2[,c(1,3)], modsAbr,
                                       Chukchi.rlq.mods, Traits)) 
View(four2CstatDoutput)
write.table(four2CstatDoutput,"Fims.3/Modality.Pearson.Correlations.txt") ## create table

ChukchiModsSig1<-as.data.frame(subset(four2CstatDoutput, adj.pvalueAxis1<0.05))
summary(ChukchiModsSig1)
ChukchiModsNotSig1<-as.data.frame(subset(four2CstatDoutput, adj.pvalueAxis1>0.05))
summary(ChukchiModsNotSig1)

ChukchiModsSig2<-as.data.frame(subset(four2CstatDoutput, adj.pvalueAxis2<0.05))
summary(ChukchiModsSig2)
ChukchiModsNotSig2<-as.data.frame(subset(four2CstatDoutput, adj.pvalueAxis2>0.05))
summary(ChukchiModsNotSig2)


##show relationship of modality and CWM-RDA axis (axes represent environmental gradients)
##Relationship with Axis 1
bl<-colorRampPalette(c("lightskyblue","royalblue","navy"))(200) 
re <- colorRampPalette(c("mistyrose", "red2","darkred"))(200)
View(four2CstatDoutput)
CRLQ1<-ggplot() + 
  geom_boxplot(data=four2CstatDoutput, aes(y = Traits, x = CS1))+
  geom_vline(xintercept = 0, linetype=2)+
  geom_label(data = ChukchiModsSig1,aes(y = Traits, x = CS1,
                                        label=modsAbr,
                                        size=abs(PearsonAxis1)))+
  geom_label(data = ChukchiModsNotSig1,aes(y = Traits, x = CS1,
                                           label=modsAbr),size=3,color="grey70")+
  scale_size_continuous(range = c(4,6))+
  xlim(-.5, .5)+
  theme_bw()+
  
  theme(axis.title = element_text(size=18),
        axis.text = element_text(size=14, color="black"),
        legend.key = element_blank(),
        legend.position = "none")+
  xlab("RLQ1 (91%)")+
  ylab("Trait")
CRLQ1
##Relationship with Axis 2; this was not included in results
CRLQ2<-ggplot() + 
  geom_boxplot(data=four2CstatDoutput, aes(y = Traits, x = CS2))+
  geom_vline(xintercept = 0,linetype = 2)+
  geom_label(data = ChukchiModsSig2,aes(y = Traits, x = CS2,
                                        label=modsAbr,
                                        size=abs(PearsonAxis2)))+
  geom_label(data = ChukchiModsNotSig2,aes(y = Traits, x = CS2,
                                           label=modsAbr),size=2,color="grey70")+
  scale_size_continuous(range = c(4,6))+
  scale_size_continuous(range = c(4,7))+
  xlim(-.5, .5)+
  theme_bw()+
  theme(axis.title = element_text(size=18),
        axis.text = element_text(size=14, color="black"),
        legend.position = "none")+
  xlab("RLQ2 (4%)")+
  ylab("Trait")
CRLQ2

C.rlq.outputs<-ggarrange(C.rlq.env.plot , CRLQ1,
                         ncol=1, nrow=2)
C.rlq.outputs
####################################################################################################
##heatmaps of modalities with Pearson correlations >0.15
ChukchiLQ<-as.data.frame(functcomp(as.matrix(ChukchiQfuzzy),
                                   as.matrix(ChukchiLtrans)))
##select BS2,BS4, BS5, FH2,LD2, LH1,  LH6, MV1, MV3, R3, 
##create heatmaps
ChukchiLQ.reduced.map<-ChukchiLQ[,c(7,9,10,12,20,22,27,28,30,34)]
head(ChukchiLQ.reduced.map)
ChukchiLQ.reduced.melt<-melt(ChukchiLQ.reduced.map)
View(ChukchiLQ.reduced.melt)
clq.mod.red<-cbind(ChukchiLQ.reduced.melt, rep(ChukchiR[,8:9],7) )
clq.mod.red2<-clq.mod.red[,c(1:4)]
View(clq.mod.red2)

my_grob = grobTree(textGrob("Alaska", x=0.45,  y=0.35, hjust=0,
                            gp=gpar(col="black", fontsize=12)))
my_Chukchi = grobTree(textGrob("Chukchi\nSea", x=0.05,  y=0.5, hjust=0, rot=50,
                               gp=gpar(col="black", fontsize=10)))
my_Beaufort = grobTree(textGrob("Beaufort Sea", x=0.65,  y=0.89, hjust=0, rot=-20,
                                gp=gpar(col="black", fontsize=10)))
world_map <- map_data("world")
ak<-subset(world_map,subregion=="Alaska")
heatmapChukchiMods<-ggplot()+
  geom_point(data=clq.mod.red2,
             aes(x=Longitude, y=Latitude, 
                 fill=value),
             show.legend = TRUE, size=2.5, shape =21)+
  scale_fill_gradient2(limits=c(0,1),
                       low = "#0072B2",
                       mid = "grey90",
                       high = "#D55E00", 
                       midpoint=.5,
                       labels = scales::percent, 
                       breaks=c(0,.25,.5, .75,1))+
  geom_map(data=ak, map=ak, aes(x=long, y=lat, map_id=region),
           color="black", fill="grey", size=0.25)+
  coord_quickmap(c(-169.5,-155), ylim = c(67,72.5))+
  theme(legend.key = element_rect(fill = NA),
        legend.direction = "horizontal",
        legend.position = c(.8,.2),
        legend.title = element_text(size=12, hjust=.4),
        legend.text = element_text(size=10),
        legend.background = element_blank(),
        axis.text.y = element_text(size = 8,color="black"),
        axis.text.x = element_text(size = 8,color="black"),
        axis.title = element_text(color="black",size=14),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), 
        panel.background = element_rect(fill = "transparent", colour = NA),  
        plot.background = element_rect(fill = "transparent", colour = NA),
        strip.text = element_text(color="black",size=14))+
  facet_wrap(~variable, ncol=4)+
  xlab(expression(paste(Longitude^o,~'W')))+
  ylab(expression(paste(Latitude^o,~'N')))+
  labs(fill="Proportion of\nmodality")+
  annotation_custom(my_grob)+
  annotation_custom(my_Chukchi)+
  guides(fill = guide_colourbar(title.position="top", title.hjust = 0.5,
                                barwidth = 8, barheight = 1))

heatmapChukchiMods

#################################################################################
##Beaufort Sea
##Traits matrix (Q)
BeaufortQ<-read.csv("Fims.3 2/BeaufortTraitbyTaxon.csv", row.names = 1) ##Read in Traits by Taxa matrix
BeaufortQfuzzy<-prep.fuzzy(BeaufortQ, c(5,5,5,3,3,6,4,4,3)) ##standardize modalities to a maximum of 1 within a trait
BeaufortQfuzzy[is.na(BeaufortQfuzzy)] <- 0 ##change NAs to zero
corBeaufortTraits<-cor(BeaufortQfuzzy) ##
BeaufortCorPlotTraits<-corrplot(corBeaufortTraits, method="number", order = "original", 
                                addCoef.col = "grey", diag = FALSE, is.corr = TRUE,
                                type="lower",tl.col = "black",
                                col=colorRampPalette(c("blue","grey70","red"))(200))


##Biomass matrix (L)
BeaufortL<-read.csv("Fims.3 2/BeaufortStationbyTaxon2.csv", row.names = 1) ##taxa by station file
BeaufortLtrans<-(BeaufortL)^(1/4) ##transform biomass matrix
BeaufortL2<-read.csv("Fims.3 2/BeaufortStationbyTaxon2.csv") ##taxa by station file
Bbiomass<-cbind(melt(BeaufortLtrans), c(rep(BeaufortL2$X,245)))
names(Bbiomass)<-c("species", "biomass", "station")
summary(Bbiomass)
ggplot()+
  geom_tile(data=Bbiomass, aes(x=station, y=species, fill=biomass))+
  scale_fill_gradient(low = "white", high = "black")##4th root transformation seems adequate
identical(rownames(BeaufortQfuzzy), colnames(BeaufortLtrans))
#Environmental matrix (R)
BeaufortR<-read.csv("Fims.3 2/BeaufortEnv.csv", row.names = 1) ##read in environmental data
BeaufortRstand<-as.data.frame(cbind(scale(BeaufortR[,c(1:7)]),BeaufortR[,c(8:9)] )) ##scale environmental data 
CorBeaufortEnv<-cor(BeaufortRstand)
BeaufortCorPlot<-corrplot(CorBeaufortEnv, method="number", order = "original", 
                               addCoef.col = "grey", diag = FALSE, is.corr = TRUE,
                               type="lower",tl.col = "black",
                          col=colorRampPalette(c("blue","grey70","red"))(200))##See Figure in Supplement
##lat/long = -0.9; we will leave both terms in the conditioned matrix
##sand/mud are highly colinear (Pearson =-0.75)
#Investigating which traits are driving functional composition
##Beaufort
##Beaufort: used gravel,sand, mud, depth, temperature,salinity, chl.a 
##To see if relationships exist between modalities and environmental 
##variables, used a 4th corner test
#fourthcorner analysis
head(BeaufortRstand)
fourthB<-fourthcorner(BeaufortRstand[,c(1,3:7)],
                      BeaufortLtrans,
                      BeaufortQfuzzy, nrepet = 4999,
                      modeltype = 6, ##model 6 incorporates model 2 and model 4 
                      p.adjust.method.G = 'fdr', 
                      p.adjust.method.D = 'fdr',) ##use false discovery rate to account for multiple permutations
plot(fourthB, x.rlq=vlt.rlqB, alpha=0.05, stat="D2")## no modalities have significant bivariate relationships with environmental variables
##ggplot
##make dataframe
modsrepB<-as.data.frame(c(rep("BF1", 6),rep("BF2", 6),rep("BF3",6),  rep("BF4",6),rep("BF5",6),
                         rep("BS1",6),rep("BS2",6),rep("BS3",6),rep("BS4",6),rep("BS5",6),
                         rep("FH1",6), rep("FH2",6), rep("FH3",6), rep("FH4",6), rep("FH5",6),
                         rep("F1",6), rep("F2",6), rep("F3",6),
                         rep("LD1",6), rep("LD2",6), rep("LD3",6),
                         rep("LH1",6), rep("LH2",6), rep("LH3",6), rep("LH4",6), rep("LH5",6), rep("LH6",6),
                         rep("MV1",6), rep("MV2",6), rep("MV3",6), rep("MV4",6),
                         rep("R1", 6), rep("R2", 6), rep("R3", 6), rep("R4",6),
                         rep("SO1",6), rep("SO2",6), rep("SO3",6)))
fourth.corner.B<-as.data.frame(cbind(as.data.frame(fourthB$tabD2$obs), 
                                     as.data.frame(fourthB$tabD2$names),
                                     as.data.frame(fourthB$tabD2$adj.pvalue),
                                     as.data.frame(modsrepB),
                                     as.data.frame(rep(c("Gravel",  "Mud",
                                                         "Depth", "Temp","Salinity", "Chl.a"),38))))
names(fourth.corner.B)<-c("Pearson","Relation", "adj.pvalue","Modality", "Env.Var")

write.table(fourth.corner.B, "Fims.3/4th.corner.beaufort.txt")
#make two dataframes for significant and nonsignficant modality -environmental variable 


Beaufort.four.corner.sig<-as.data.frame(subset(fourth.corner.B,adj.pvalue<0.05))
Beaufort.four.corner.notsig<-as.data.frame(subset(fourth.corner.B,adj.pvalue>0.05))

bl2<-colorRampPalette(c("navy","royalblue","lightskyblue", "white"))(200) 
re <- colorRampPalette(c("white", "mistyrose", "red2","darkred"))(200)

level_order <- factor(fourth.corner.B$Env.Var, level = c("Gravel", "Mud",
                                                         "Depth", "Temp","Salinity", "Chl.a"))
fourth.corner.beaufort.plot<-ggplot()+
  geom_tile(data=Beaufort.four.corner.sig, aes(x=Env.Var, y=fct_rev(Modality),
                                               fill=Pearson))+
  scale_fill_gradient2(low=bl2, mid = "white", high = re, limits = c(-.26,.26))+
  geom_text(data=Beaufort.four.corner.sig, aes(x=Env.Var, y=fct_rev(Modality), 
                                               label=round(Pearson,2)),color="white")+
  theme_classic()+
  theme(axis.text = element_text(color="black", size=12),
        axis.title = element_text(color="black", size=14))+
  geom_tile(data=Beaufort.four.corner.notsig, aes(x=Env.Var,y=fct_rev(Modality)),
            fill="grey50", color="black")+
  scale_y_discrete(limits = rev(unique(sort(fourth.corner.B$Modality))))+
  xlab("")+
  ylab("Modality")

fourth.corner.beaufort.plot
ggarrange(fourth.corner.chukchi.plot, fourth.corner.beaufort.plot, ncol=2, 
          common.legend = TRUE,
          legend = "bottom")

##RLQ analysis
dudiLB <- dudi.coa (BeaufortLtrans, scannf = FALSE) ##biomass
dudiRB <- dudi.pca (BeaufortRstand[,c(1,3:7)], scannf = FALSE, row.w = dudiLB$lw)##env
dudiQB <- dudi.pca (BeaufortQfuzzy, scannf = FALSE, row.w = dudiLB$cw)##traits
##plot ordinations for supplement
biplot(dudiLB)
biplot(dudiRB)
biplot(dudiQB)

vlt.rlqB <- rlq (dudiR = dudiRB, dudiL = dudiLB, dudiQ = dudiQB, scannf = FALSE)
randtest(vlt.rlqB, nrepet = 4999) ##both models are significant
plot(randtest(vlt.rlqB, modeltype = 6))
summary(vlt.rlqB) ##for Table 2
##inertia: 0.484
##eigen.values: 0.399, 0.042, 0.026
##proj. inertia (Axis1):82.43%
##proj. inertia (Axis2): 8.59%

##Global test
Brlq<-fourthcorner2(BeaufortRstand[,c(1,3:7)],BeaufortLtrans, BeaufortQfuzzy,
                    modeltype = 6, p.adjust.method.G = "fdr", nrepet=4999) 
summary(Brlq)
##obs: 0.513
##p.value = 0.006
##which environmental variables are significant to RLQ trait axes
four42B<-fourthcorner.rlq(vlt.rlqB, modeltype=6,
                          p.adjust.method.G = "fdr",
                          p.adjust.method.D = "fdr",
                          typetest = "R.axes", nrepet = 4999) ##test environmental variables against modality axes
plot(four42B, alpha=0.05, type="biplot") ##salinity and depth are significant to Q-axes 
##

Beaufort.rlq.mods<-as.data.frame(vlt.rlqB$c1)
Beaufort.rlq.env<-as.data.frame(cbind((vlt.rlqB$li),c("Gravel",
                                                      "Mud","Depth", "Temperature",
                                                      "Salinity", "Chl.a" )))
names(Beaufort.rlq.env)[3]<-"Env"
head(Beaufort.rlq.env)
##plot Beaufort rlq.env.matrix
B.rlq.env.plot<-ggplot()+
  geom_hline(yintercept = 0, linetype = 2) +
  geom_vline(xintercept = 0, linetype = 2)+
  geom_segment(data=Beaufort.rlq.env[c(1,2,4,6),], aes(x=0, xend=Axis1, y=0, yend=Axis2),
               alpha=1, size=.4, color="grey50",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_segment(data=Beaufort.rlq.env[c(3,5),], aes(x=0, xend=Axis1, y=0, yend=Axis2),
               alpha=1, size=.4, color="black",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_label(data=Beaufort.rlq.env[c(1,2,4,6),], aes(x=Axis1, y=Axis2,
                                                   label=Env),size=5, color="grey50")+
  geom_label(data=Beaufort.rlq.env[c(3,5),], aes(x=Axis1, y=Axis2,
                                                     label=Env),size=5, color="black")+
  theme_bw()+
  theme(axis.title = element_text(size=18))+
  xlim(-0.25, 0.75)+
  ylim(-0.25, 0.25)+
  xlab("Projected inertia (82%): Axis 1")+
  ylab("Projected inertia (9%): Axis 2")
B.rlq.env.plot  

#RLQ-4th corner analysis Beaufort:
four2B<-fourthcorner.rlq(vlt.rlqB, modeltype=6,
                         p.adjust.method.G = "fdr",
                         p.adjust.method.D = "fdr",
                         typetest = "Q.axes", nrepet=4999) ##test modalities against environmental gradient
plot(four2B, alpha=.05,type ="biplot") #show modalities that have significant (p<0.05) relationships  
##
#make data frames for significant and non-significant modalities
##using 4thcorner-RLQ test for "Q-axes" 
##use ggplot for representation
four2Bboutput<-as.data.frame(cbind(as.data.frame(four2B$tabD2$obs), 
                                  as.data.frame(four2B$tabD2$names),
                                  as.data.frame(four2B$tabD2$adj.pvalue)))
names(four2Bboutput)<-c("Pearson","Relation", "adj.pvalue")
summary(four2Bboutput)
##plot the relationship of significant modalities along the RLQ axis
modB<-c("BF1", "BF2", "BF3", "BF4", "BF5",
        "BS1", "BS2", "BS3", "BS4", "BS5",
        "FH1", "FH2", "FH3", "FH4", "FH5",
        "F1", "F2", "F3",
        "LD1", "LD2", "LD3", 
        "LH1", "LH2", "LH3", "LH4", "LH5", "LH6",
        "MV1",  "MV2", "MV3", "MV4",
        "RS1", "RS2", "RS3", "RS4",
        "SO1", "SO2", "SO3")
TraitsB<-c(rep("Body form", 5),rep("Body size", 5), rep("Feeding habit", 5),
           rep("Fragility",3), rep("Larval development", 3), rep("Living habit", 6),
           rep("Movement",4), rep("Reproductive strategy", 4), rep("Sociability",3))

##make 2 data frames: 
four2BSubsetaxis1 <- four2Bboutput[grep("AxcR1", four2Bboutput$Relation), ]
names(four2BSubsetaxis1)<-c("PearsonAxis1", "RelationAxis1", "adj.pvalueAxis1")
four2BSubsetaxis2<-four2Bboutput[grep("AxcR2", four2Bboutput$Relation), ]
head(four2BSubsetaxis2)
names(four2BSubsetaxis2)<-c("PearsonAxis2", "RelationAxis2", "adj.pvalueAxis2")

four2BstatDoutput<-as.data.frame(cbind(four2BSubsetaxis1[,c(1,3)],four2BSubsetaxis2[,c(1,3)], modB,
                                       Beaufort.rlq.mods, TraitsB))
View(four2BstatDoutput)
summary(four2BstatDoutput)
BeaufortModsSig<-as.data.frame(subset(four2BstatDoutput, adj.pvalueAxis1<0.05 ))
BeaufortModsNotSig<-as.data.frame(subset(four2BstatDoutput, adj.pvalueAxis1>0.05))

BeaufortModSig2<-as.data.frame(subset(four2BstatDoutput, adj.pvalueAxis2<0.05 ))
BeaufortModsNotSig2<-as.data.frame(subset(four2BstatDoutput, adj.pvalueAxis2>0.05))

##show relationship of modality and RLQ axis (axes represent environmental gradients)
##Relationship with Axis 1
View(four2BstatDoutput)
BRLQ1<-ggplot() + 
  geom_boxplot(data=four2BstatDoutput, aes(y = TraitsB, x = CS1))+
  geom_vline(xintercept = 0,linetype = 2)+
  geom_label(data = BeaufortModsSig,aes(y = TraitsB, x = CS1,
                                        label=modB,
                                        size= abs(PearsonAxis1)))+
  geom_label(data = BeaufortModsNotSig,aes(y = TraitsB, x = CS1,
                                           label=modB),size=3,color="grey70")+
  scale_size_continuous(range = c(4,6))+
  xlim(-.5, .5)+
  theme_bw()+
  theme(axis.title = element_text(size=18),
        axis.text = element_text(size=14, color="black"),
        legend.position = "none")+
  xlab("RLQ1 (82%)")+
  ylab("Trait")
BRLQ1
##Relationship with Axis 2 (not shown in results)
BRLQ2<-ggplot() + 
  geom_boxplot(data=four2BstatDoutput, aes(y = TraitsB, x = CS2))+
  geom_vline(xintercept = 0,linetype = 2)+
  geom_label(data = BeaufortModsSig,aes(y = TraitsB, x = CS2,
                                        label=modB,
                                        color=PearsonAxis2,
                                        size=PearsonAxis2))+
  geom_label(data = BeaufortModsNotSig2,aes(y = TraitsB, x = CS2,
                                           label=modB),size=3,color="grey70")+
  scale_color_gradient2(low=bl2, mid="grey50", high = re,midpoint=0.0, limits = c(-.26,.26))+
  xlim(-.5, .5)+
  theme_bw()+
  theme(axis.title = element_text(size=18),
        axis.text = element_text(size=14, color="black"),
        legend.position = "none")+
  xlab("RLQ2 (9%)")+
  ylab("Trait")
BRLQ2

B.rlq.outputs<-ggarrange(B.rlq.env.plot,BRLQ1,
          ncol=1, nrow=2)
##combine Chukchi and Beaufort rlq results
ggarrange(C.rlq.outputs, B.rlq.outputs, 
          ncol=2)

####################################################################################################
##heatmaps of modalities with Pearson correlations >0.1
BeaufortLQ<-as.data.frame(functcomp(as.matrix(BeaufortQfuzzy),
                                    as.matrix(BeaufortLtrans)))
##select modalities with Pearson values >.1 : BS2, BS4, LD2, MV3,
BeaufortLQ.mods.reduced.maps<-BeaufortLQ[,c(9,20)]
head(BeaufortLQ.mods.reduced.maps)
BeaufortLQ.mods.reduced.melt<-melt(BeaufortLQ.mods.reduced.maps)
blq.mod.red<-cbind(BeaufortLQ.mods.reduced.melt, rep(BeaufortR[,8:9],6) )
blq.mod.red2<-blq.mod.red[,c(1:4)]

my_grobB = grobTree(textGrob("Alaska", x=0.3,  y=0.1, hjust=0,
                            gp=gpar(col="black", fontsize=12)))
my_Chukchi = grobTree(textGrob("Chukchi\nSea", x=0.05,  y=0.5, hjust=0, rot=50,
                               gp=gpar(col="black", fontsize=10)))
my_BeaufortB = grobTree(textGrob("Beaufort Sea", x=0.65,  y=0.7, hjust=0, rot=-20,
                                gp=gpar(col="black", fontsize=10)))
world_map <- map_data("world")
ak<-subset(world_map,subregion=="Alaska")
heatmapBeaufortMods<-ggplot()+
  geom_point(data=blq.mod.red2,
             aes(x=Longitude, y=Latitude, 
                 fill=value),
             show.legend = TRUE, size=2.5, shape =21)+
  scale_fill_gradient2(limits=c(0,.45),
                       low = "#0072B2",
                       mid = "grey90",
                       high = "#D55E00", 
                       midpoint=.2,
                       labels = scales::percent, 
                       breaks=c(0,.15,.30, .45))+
  geom_map(data=ak, map=ak, aes(x=long, y=lat, map_id=region),
           color="black", fill="grey", size=0.25)+
  coord_quickmap(c(-155,-140), ylim = c(69.5,72.5))+
  theme(legend.key = element_rect(fill = NA),
        legend.direction = "horizontal",
        legend.position = "right",
        legend.title = element_text(size=14, hjust=.4),
        legend.text = element_text(size=12),
        legend.background = element_blank(),
        axis.text.y = element_text(size = 8,color="black"),
        axis.text.x = element_text(size = 8,color="black"),
        axis.title = element_text(color="black",size=14),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), 
        panel.background = element_rect(fill = "transparent", colour = NA),  
        plot.background = element_rect(fill = "transparent", colour = NA),
        strip.text = element_text(color="black",size=14))+
  facet_wrap(~variable, ncol=4, nrow =1 )+
  xlab(expression(paste(Longitude^o,~'W')))+
  ylab(expression(paste(Latitude^o,~'N')))+
  annotation_custom(my_grobB)+
  annotation_custom(my_BeaufortB)+
  guides(fill = guide_colourbar(title.position="bottom", title.hjust = 0.5,
                                barwidth = 8, barheight = 1,title = "Proportion of modality"))

heatmapBeaufortMods

##combine sea heatmaps
ggarrange( heatmapChukchiMods,heatmapBeaufortMods, 
           ncol=1,  widths=c(2,1), heights=c(3,1))
####################################################################################################
###Environmental heatmaps / FDis heatmap
head(ChukchiR)
##find fdisp for each shelf:
##FDis Beaufort
BeaufortSpeciesTraitsdist<-gowdis(BeaufortQfuzzy) ##created a gower distance matrix of species based on traits
FDisBeaufort<-fdisp(BeaufortSpeciesTraitsdist, 
                    as.matrix(BeaufortLtrans)) ##Find functional dispersion of stations

hist(FDisBeaufort$FDis)
##make dataframe of FDis and Lat for both seas
ChukchiSpeciesTraitsdist<-gowdis(ChukchiQfuzzy) ##created a gower distance matrix of species based on traits
FDisChukchi<-fdisp(ChukchiSpeciesTraitsdist, 
                    as.matrix(ChukchiLtrans)) ##Find functional dispersion of stations

ChukchiR2<-as.data.frame(cbind(ChukchiR, as.data.frame(FDisChukchi$FDis),
                               as.data.frame(rep("Chukchi",67))))
names(ChukchiR2)[10:11]<-c("FDis", "Sea")
head(ChukchiR2)

BeaufortR2<-as.data.frame(cbind(BeaufortR$Gravel, BeaufortR$Sand, BeaufortR$Mud,
                  BeaufortR$Depth, BeaufortR$Temp, BeaufortR$Salinity,
                  BeaufortR$Chl.a, BeaufortR$Latitude, BeaufortR$Longitude,
                  as.data.frame(FDisBeaufort$FDis), rep("Beaufort", 46)))
names(BeaufortR2)<-c("Gravel", "Sand", "Mud", "Depth", "Temp", "Salinity", "Chl.a",
                     "Latitude", "Longitude", "FDis", "Sea")
head(BeaufortR2)

##Combine 2 dataframes
Both.seas<-rbind(ChukchiR2, BeaufortR2)
View(Both.seas)
##Make env. variable to the same scale (0-1)
Sal01<-{(Both.seas$Salinity-min(Both.seas$Salinity))/
    (max(Both.seas$Salinity)-min(Both.seas$Salinity))}

Depth01 <-{(Both.seas$Depth-min(Both.seas$Depth))/
    (max(Both.seas$Depth)-min(Both.seas$Depth))}
##Chlorophyll has one point that is very high
##I changed this one point to the second highest value so
##we can see patterns
View(Both.seas$Chl.a)
##row 77
Both.seas[77, 7] = 22
Chla01 <-{(Both.seas$Chl.a-min(Both.seas$Chl.a))/
    (max(Both.seas$Chl.a)-min(Both.seas$Chl.a))}

Temp01 <-{(Both.seas$Temp-min(Both.seas$Temp))/
    (max(Both.seas$Temp)-min(Both.seas$Temp))}
FDis01<-{(Both.seas$FDis-min(Both.seas$FDis))/
    (max(Both.seas$FDis)-min(Both.seas$FDis))}

Both.seas2<-as.data.frame(cbind(as.data.frame(Both.seas$Gravel/100),
                           as.data.frame(Both.seas$Mud/100),
                           as.data.frame(Both.seas$Sand/100),
                           as.data.frame(Chla01),
                           as.data.frame(Depth01),
                           as.data.frame(Sal01),
                           as.data.frame(Temp01), 
                           as.data.frame(Both.seas$Latitude),
                           as.data.frame(Both.seas$Longitude),
                           as.data.frame(FDis01), 
                           as.data.frame(Both.seas$Sea)))
View(Both.seas2)
names(Both.seas2)<-c("Gravel", "Mud", "Sand", "Chlorophyll-a", "Depth",
                     "Salinity","Temperature","Latitude", "Longitude",
                     "FDis","Sea" )

##heatmaps
Both.seas.melt<-melt(Both.seas2, id=c("Sea", "Latitude", "Longitude"))
View(Both.seas.melt)

my_grob_env = grobTree(textGrob("Alaska", x=0.4,  y=0.4, hjust=0,
                             gp=gpar(col="black", fontsize=12)))
my_Chukchi_env = grobTree(textGrob("Chukchi\nSea", x=0.075,  y=0.5, hjust=0, rot=50,
                               gp=gpar(col="black", fontsize=10)))
my_Beaufort_env = grobTree(textGrob("Beaufort Sea", x=0.65,  y=0.9, hjust=0, rot=-20,
                                 gp=gpar(col="black", fontsize=10)))
world_map <- map_data("world")
ak<-subset(world_map,subregion=="Alaska")

heatmap.both.seas.env<-ggplot()+
  geom_point(data=Both.seas.melt,
             aes(x=Longitude, y=Latitude, 
                 fill=value),
             show.legend = TRUE, size=2.5, shape =21)+
  scale_fill_gradient2(limits=c(0,1),
                       low = "#0072B2",
                       mid = "white",
                       high = "#D55E00", 
                       midpoint=.5,
                       labels = scales::percent, 
                       breaks=c(0,.25,.5, .75,1))+
  geom_map(data=ak, map=ak, aes(x=long, y=lat, map_id=region),
           color="black", fill="grey", size=0.25)+
  coord_quickmap(c(-169.5,-140), ylim = c(67,72.5))+
  theme(legend.key = element_rect(fill = NA),
        legend.direction = "vertical",
        legend.position = "none",
        legend.title = element_text(size=14, hjust=.4),
        legend.text = element_text(size=12),
        legend.background = element_blank(),
        axis.text.y = element_text(size = 8,color="black"),
        axis.text.x = element_text(size = 8,color="black"),
        axis.title = element_text(color="black",size=14),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), 
        panel.background = element_rect(fill = "transparent", colour = NA),  
        plot.background = element_rect(fill = "transparent", colour = NA),
        strip.text = element_text(color="black",size=14))+
  facet_wrap(~variable, ncol=2 )+
  xlab(expression(paste(Longitude^o,~'W')))+
  ylab(expression(paste(Latitude^o,~'N')))+
  annotation_custom(my_grob_env)+
  annotation_custom(my_Beaufort_env)+
  annotation_custom(my_Chukchi_env)+
  guides(fill = guide_colourbar(title.position="top", title.hjust = 0.5,
                                barwidth = 1, barheight = 8))+
  scalebar(x.min = -163, x.max = -158,
           y.min = 67.5, y.max = 68.5,
           dist = 100, model = "WGS84",
           dist_unit = "km", transform = TRUE,
           height = .25, st.bottom = TRUE, 
           st.dist=0.15, st.size = 3,
           st.color = "black", box.fill = c("black", "white"),
           box.color = "black", border.size = .1)

heatmap.both.seas.env
####################################################################################################
##Boxplots
##compare variability of environmental variables and variability/mean of FDis
head(Both.seas2) ##remove lat and long columns
Both.seas.boxplots<-melt(Both.seas2[,c(1:7,10:11)], id=c("Sea"))
head(Both.seas.boxplots)
Both.seas.boxplots$Sea <- factor(Both.seas.boxplots$Sea ,levels = c("Chukchi", "Beaufort"))
Both.seas.boxplots.plots<-ggplot()+
  geom_boxplot(data=Both.seas.boxplots, aes(x=Sea, y=value, fill=Sea))+
  facet_wrap(~variable, ncol = 8, scales="free")+
  theme_bw()+
  theme(legend.position = "none")+
  scale_fill_grey(start = 0.4, end = 0.8)+
  xlab("")+
  ylab("")
                      
Both.seas.boxplots.plots

##test difference in environmental gradients for variance and FDis for significance and variance
# Fit spatial autocorrelation within each sea and with nugget:
# (nugget=F forces intercept of 0)
mod3b<-gls(FDis~Sea, method="ML",
          corExp(form = ~ Latitude + Longitude | Sea,
                 nugget = TRUE),
          data=Both.seas)
summary(mod3b)  # Difference between seas even less significant
plot(Variogram(mod3b))  # Looks much bettre (points at large distances are based on far
                        # fewer data points and less reliable)
# Usually, check for presence of autocorrelation with the full model:
mod3c<-gls(FDis~Sea, method="ML",
           data=Both.seas)
AICc(mod3b, mod3c)  # clear evidence of autocorrelation
anova(mod3b, mod3c)
R2.1 <- 1 - with(Both.seas, (sum((FDis-predict(mod3b))^2)/sum((FDis-mean(FDis))^2)))
R2.1
##0.009 rsquared
mod4<-gls(FDis~1, method="ML",
          corExp(form = ~ Latitude + Longitude | Sea,
                 nugget = TRUE),
          data=Both.seas)
anova(mod3b, mod4)##no significant different in FDis between seas
AICc(mod3b, mod4)

##levene_test
# Levene's test with one independent variable
head(Both.seas)
GravelLT<-leveneTest(Gravel ~ Sea, data = Both.seas) ##no difference
SandLT<-leveneTest(Sand ~ Sea, data = Both.seas) ##significant
MudLT<-leveneTest(Mud ~ Sea, data = Both.seas) ##significant
DepthLT<-leveneTest(Depth ~ Sea, data = Both.seas)##significant
TempLT<-leveneTest(Temp ~ Sea, data = Both.seas) ##significant
SalinityLT<-leveneTest(Salinity ~ Sea, data = Both.seas) ##not significant
Chl.aLT<-leveneTest(Chl.a ~ Sea, data = Both.seas) ##not significant
FDisLT<-leveneTest(FDis ~ Sea, data = Both.seas) ##significant
LTall<-as.data.frame(cbind(c("Gravel", "Sand", "Mud", "Depth", "Temperature", 
                             "Salinity", "Chlorophyll-a", "FDis"),
                      rbind(GravelLT$`F value`,
                           SandLT$`F value`,
                           MudLT$`F value`,
                           DepthLT$`F value`,
                           TempLT$`F value`,
                           SalinityLT$`F value`,
                           Chl.aLT$`F value`,
                           FDisLT$`F value`),
                      rbind(GravelLT$`Pr(>F)`,
                            SandLT$`Pr(>F)`,
                            MudLT$`Pr(>F)`,
                            DepthLT$`Pr(>F)`,
                            TempLT$`Pr(>F)`,
                            SalinityLT$`Pr(>F)`,
                            Chl.aLT$`Pr(>F)`,
                            FDisLT$`Pr(>F)`)))
LTboth.seas<-LTall[,c(1,2,4)]
names(LTboth.seas)<-c("Environmental variable", "F statistic", "p-value")
View(LTboth.seas)
##signficantly difference in variability for sand, mud, depth, temp, FDis
getwd()
write.table(LTboth.seas, "Fims.3 2/LevenesTest.txt", sep="\t")
##variance is significantly different between seas
##combine environmental/FDis heatmaps and environmental/FDis box plots
ggarrange(heatmap.both.seas.env,Both.seas.boxplots.plots,
          ncol = 1, heights = c(3,1))


####################################################################################################
##CWM-RDA, FDis, FDis~CWM-RDA per shelf
##Chukchi
##remove sand bc mud and sand are highly correlated (-0.8)
##run cwm-rda model with spatial coordinates as a condition matrix:
##Use LQ matrix as response variable
RDA_modelc.reduced <- rda( ChukchiLQ ~ .+Condition(as.matrix(ChukchiRstand[,8:9])), 
                   data = ChukchiRstand[,c(1,3:5,7)])
vif.cca(RDA_modelc.reduced) ##although temp is high, we left it in
plot(RDA_modelc.reduced)
summary(RDA_modelc.reduced)
##conditioned: 28%
##constrained RDA1:26% (75%; RDA2:17%)
##unconstrained: 45%
RsquareAdj(RDA_modelc.reduced)##0.23
Chukchi.cwm.rda<-plot(RDA_modelc.reduced)
anova(RDA_modelc.reduced) ##p=0.001
anova(RDA_modelc.reduced, by="axis") ##RDA1, RDA2
anova(RDA_modelc.reduced, by="margin") ##gravel, mud, depth, temp are significant; chl.a is not
ChukchiCWMRDAplot<-plot(RDA_modelc.reduced)

##plot cwm-RDA
Chukchi.cwm.rda.sites<-as.data.frame(ChukchiCWMRDAplot$sites)
Chukchi.cwm.rda.env<-as.data.frame(cbind(as.data.frame(ChukchiCWMRDAplot$biplot),  
                                         c("Gravel", "Mud", "Depth", "Temperature",
                                            "Chl.a")))

head(Chukchi.cwm.rda.env)
names(Chukchi.cwm.rda.env)[3]<-"Env"
ChukchiCWMRDA<-ggplot()+
  geom_hline(yintercept = 0, linetype = 2) +
  geom_vline(xintercept = 0, linetype = 2)+
  geom_segment(data=Chukchi.cwm.rda.env[c(2:4),], aes(x=0, xend=RDA1, y=0, yend=RDA2),
               alpha=1, size=.4, color="black",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_segment(data=Chukchi.cwm.rda.env[c(1,5),], aes(x=0, xend=RDA1, y=0, yend=RDA2),
               alpha=1, size=.4, color="grey",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_point(data=Chukchi.cwm.rda.sites, aes(x=RDA1, y=RDA2), size=3)+
  geom_label(data=Chukchi.cwm.rda.env[c(2:4),], aes(x=RDA1, y=RDA2,
                                                   label=Env),size=5, color="black")+
  geom_label(data=Chukchi.cwm.rda.env[c(1,5),], aes(x=RDA1, y=RDA2,
                                                       label=Env),size=5, color="grey")+
  xlab("RDA1 (75%)")+
  ylab("RDA2 (17%)")+
  xlim(-1, 1)+
  ylim(-1.5, 1)+
  theme_bw()+
  theme(axis.title = element_text(size=18))
ChukchiCWMRDA

##Compare to FDis
##Compare station locations on CWM-RDA Axis 1 and 2 to FDis to see if 
##expected environmental filter (e.g., dome-shaped relationship is present)
##FDisp


hist(FDisChukchi$FDis) ##look at spready of functional dispersion

##test for the relationship of FDis ~ Axis 1 of cwm-rda
ChukchiFDisRDAFull<-as.data.frame(cbind(FDisChukchi$FDis,
                                        Chukchi.cwm.rda.sites,##use CWM-RDA site locations
                                        ChukchiR$Latitude,
                                        ChukchiR$Longitude))
names(ChukchiFDisRDAFull)[1:5]<-c("FDis", "Axis1","Axis2", "Lat", "Long")
##test for spatial autocorrelation of FDis among RDA1 axis
CmodFDisSAC<-gls(FDis~1, 
                 correlation = corExp(form = ~ Lat + Long, 
                                      nugget = FALSE),
                 data=ChukchiFDisRDAFull)

CmodFDisNoSAC<-gls(FDis~1,
                   data=ChukchiFDisRDAFull)
anova(CmodFDisSAC, CmodFDisNoSAC)##models are significantly different
##Use AICc to account for small sample size
AICc(CmodFDisSAC, CmodFDisNoSAC) ##model that accounts for spatial autocorrelation has a lower AICc
##test FDis to Axis 1 and 2 
CmodFDisRDA1<-gls(FDis~poly(Axis1,2)+poly(Axis2,2),
                  correlation = corExp(form = ~ Lat + Long, 
                                       nugget = FALSE),
                  method="ML",
                  data=ChukchiFDisRDAFull)
summary(CmodFDisRDA1)##model is significant / polynomial terms for RDA2 is signficant

# with nugget:
CmodFDisRDA1b<-gls(FDis~poly(Axis1,2)+poly(Axis2,2),
                  correlation = corExp(form = ~ Lat + Long, 
                                       nugget = TRUE),
                  method="ML",
                  data=ChukchiFDisRDAFull)
summary(CmodFDisRDA1b)
AICc(CmodFDisRDA1b, CmodFDisRDA1)
plot(Variogram(CmodFDisRDA1))

##try model with linear relationship for Axis 1 and quadratic for Axis 2
CmodFDisRDA2<-gls(FDis~poly(Axis1,1)+poly(Axis2,2),
                  correlation = corExp(form = ~ Lat + Long, 
                                       nugget = FALSE),
                  method="ML",
                  data=ChukchiFDisRDAFull)
summary(CmodFDisRDA2)##model is signifcant
anova(CmodFDisRDA1, CmodFDisRDA2) ##no difference, go with more simple model
AICc(CmodFDisRDA1, CmodFDisRDA2)
##we went with CmodFDisRDA2: linear relationship for first axis and quadratic for second axis
##compare to null
CmodFDisNull<-gls(FDis~1,
                  correlation = corExp(form = ~ Lat + Long, 
                                       nugget = FALSE),
                  method="ML",
                  data=ChukchiFDisRDAFull)
anova(CmodFDisRDA2, CmodFDisNull) ##models are significantly different
AICc(CmodFDisRDA2, CmodFDisNull) ##CmodFDisRDA2 is the better model with the lower AICc

##look at relationship of FDis to RDA1
ChukchiFDisToRDA1<-ggplot()+
  geom_vline(xintercept = 0, linetype=2)+
  geom_point(data=ChukchiFDisRDAFull, aes(x=Axis1, y=FDis))+
  geom_smooth(data=ChukchiFDisRDAFull, aes(x=Axis1, y=FDis),
              method="lm",formula = y~poly(x,1))+
  xlab("RDA1 (75%)")+
  ylab("Functional Dispersion (FDis)")+
  theme_bw()+
  theme(axis.title = element_text(size=18))
ChukchiFDisToRDA1

##look at relationship of FDis to RDA2
ChukchiFDisToRDA2<-ggplot()+
  geom_vline(xintercept = 0, linetype=2)+
  geom_point(data=ChukchiFDisRDAFull, aes(x=Axis2, y=FDis))+
  geom_smooth(data=ChukchiFDisRDAFull, aes(x=Axis2, y=FDis),
              method="lm",formula = y~poly(x,2))+
  xlab("RDA2 (17%)")+
  ylab("Functional Dispersion (FDis)")+
  theme_bw()+
  theme(axis.title = element_text(size=18))
ChukchiFDisToRDA2

c.fdis.plots<-ggarrange(ChukchiCWMRDA,  ChukchiFDisToRDA1, ChukchiFDisToRDA2, 
          ncol=1, nrow=3)

##removed Beaufort comparison of RDA1 in results (used as a place holder for )
####################################################################################################
##CWM-RDA, FDis, FDis~Sea, FDis~CWM-RDA per shelf
##Beaufort
##Use BeaufortLQ matrix as response variable
##Condition matrix includes lat and long
##standardized env. matrix (minus lat and long)
RDA_model2Beaufort <- rda( BeaufortLQ ~ .+Condition(as.matrix(BeaufortRstand[,c(8,9)])), 
                           data = BeaufortRstand[,c(1:7)])
vif.cca(RDA_model2Beaufort)
##remove depth and sand to lower vif of terms
head(BeaufortRstand)
RDA_model2Beaufort.reduced <- rda( BeaufortLQ ~ .+Condition(as.matrix(BeaufortRstand[,c(8,9)])), 
                           data = BeaufortRstand[,c(1,3,5:7)])
vif.cca(RDA_model2Beaufort.reduced)
plot(RDA_model2Beaufort.reduced)
summary(RDA_model2Beaufort.reduced)
##conditioned: 35%
##constrained RDA1:9% (49%; RDA2:24%, RDA3:19%)
##unconstrained: 56%
anova(RDA_model2Beaufort.reduced) ##p=0.158
##RDA_model2Beaufort.reduced is not significant
anova(RDA_model2Beaufort.reduced, by="axis") ##no axes are significant
anova(RDA_model2Beaufort.reduced, by="margin") ##no environmental variables are significant
RsquareAdj(RDA_model2Beaufort.reduced) ##0.023

BeaufortCWMRDAplot<-plot(RDA_model2Beaufort.reduced)
p<-lm(Depth~Latitude+Longitude, data=BeaufortRstand)
summary(p) ##adj. rsq = 0.86; p<0.001; depth is highly signficant to lat + long
##plot cwm-RDA
Beaufort.cwm.rda.sites<-as.data.frame(BeaufortCWMRDAplot$sites)
Beaufort.cwm.rda.env<-as.data.frame(cbind(as.data.frame(BeaufortCWMRDAplot$biplot),  
                                          c( "Gravel", "Mud", "Temperature", "Salinity", "Chl.a")))
names(Beaufort.cwm.rda.env)<-c("RDA1", "RDA2", "Env")
##ggplot BCWM-RDA
head(Beaufort.cwm.rda.env)
BeaufortCWMRDA<-ggplot()+
  geom_hline(yintercept = 0, linetype = 2) +
  geom_vline(xintercept = 0, linetype = 2)+
   geom_segment(data=Beaufort.cwm.rda.env[c(1:5),], aes(x=0, xend=RDA1, y=0, yend=RDA2),
               alpha=1, size=.4, color="grey",
               arrow = arrow(length = unit(.2,"cm")))+
  geom_point(data=Beaufort.cwm.rda.sites, aes(x=RDA1, y=RDA2), size=3)+
  geom_label(data=Beaufort.cwm.rda.env[c(1:5),], aes(x=RDA1, y=RDA2,
                                                       label=Env),size=5, color="grey")+
  xlab("RDA1 (49%)")+
  ylab("RDA2 (24%)")+
  xlim(-1.1, 1.5)+
  ylim(-1.25, 1.1)+
  theme_bw()+
  theme(axis.title = element_text(size=18))
BeaufortCWMRDA


##Compare to FDis
##Compare station locations on CWM-RDA Axis 1 to FDis to see if 
##expected environmental filter (e.g., dome-shaped relationship is present)
##FDisp
##however, these results are shown in the manuscript as the cwm-rda relationship is not signficant


##test for the relationship of FDis ~ Axis 1 of cwm-rda
##test for the relationship of FDis ~ Axis 1 of cwm-rda
BeaufortFDisRDAFull<-as.data.frame(cbind(FDisBeaufort$FDis,
                                         Beaufort.cwm.rda.sites,##use CWM-RDA site locations
                                         BeaufortR$Latitude,
                                         BeaufortR$Longitude))
names(BeaufortFDisRDAFull)[1:5]<-c("FDis", "Axis1","Axis2", "Lat", "Long")

##test for spatial autocorrelation of FDis among RDA1 axis

BmodFDisSAC<-gls(FDis~1, 
                 correlation = corExp(form = ~ Lat + Long, 
                                      nugget = FALSE),
                 data=BeaufortFDisRDAFull)
BmodFDisNoSAC<-gls(FDis~1,
                   data=BeaufortFDisRDAFull)
anova(BmodFDisSAC, BmodFDisNoSAC)##models are not significantly different

plot(Variogram(BmodFDisSAC)) # Evidence of nugget!
# Model with nugget:
BmodFDisSAC.b <-gls(FDis~1, 
                 correlation = corExp(form = ~ Lat + Long, 
                                      nugget = TRUE),
                 data=BeaufortFDisRDAFull)
AICc(BmodFDisSAC, BmodFDisSAC.b)
##No spatial autocorrelation
##use lm() 

##test FDis to Axis 1 and 2 
BmodFDisRDA1<-lm(FDis~poly(Axis1,2)+poly(Axis2,2),
                 data=BeaufortFDisRDAFull)

summary(BmodFDisRDA1)##model is significant

BmodFDisRDA2<-lm(FDis~poly(Axis1,2),
                 data=BeaufortFDisRDAFull)

summary(BmodFDisRDA2)##model is significant
anova(BmodFDisRDA1, BmodFDisRDA2)
AICc(BmodFDisRDA1, BmodFDisRDA2)## No big difference; go with BmodFDisRDA2

##compare to null model
BmodFDisNull<-lm(FDis~1,
                 data=BeaufortFDisRDAFull)
anova(BmodFDisRDA2, BmodFDisNull) ##models are significantly different
AICc(BmodFDisRDA2, BmodFDisNull) ##CmodFDisRDA1 is the better model with the lower AICc
visreg(BmodFDisRDA2)

##visualize in ggplot
##look at relationship of FDis to RDA1 / RDA2
BeaufortFDisToRDA1<-ggplot()+
  geom_vline(xintercept = 0,linetype = 2)+
  geom_point(data=BeaufortFDisRDAFull, aes(x=Axis1, y=FDis))+
  geom_smooth(data=BeaufortFDisRDAFull, aes(x=Axis1, y=FDis),
              method="lm",formula = y~poly(x,2))+
  xlab("RDA1 (49%)")+
  ylab("Functional Dispersion (FDis)")+
  theme_bw()+
  theme(axis.title = element_text(size=18))
BeaufortFDisToRDA1

BeaufortFDisToRDA2<-ggplot()+
  geom_vline(xintercept = 0,linetype = 2)+
  geom_point(data=BeaufortFDisRDAFull, aes(x=Axis2, y=FDis))+
  geom_smooth(data=BeaufortFDisRDAFull, aes(x=Axis2, y=FDis),
              method="gam",formula = y~poly(x,2))+
  xlab("RDA2 (24%)")+
  ylab("Functional Dispersion (FDis)")+
  theme_bw()+
  theme(axis.title = element_text(size=18))
BeaufortFDisToRDA2

b.fdis.plots<-ggarrange(BeaufortCWMRDA,BeaufortFDisToRDA1,
          ncol = 1, nrow=3)
ggarrange(c.fdis.plots, b.fdis.plots)
##removed Beaufort plot relating cwm-rda axis 1 to fdis
##cwm-rda model was significant so we only presented the cwm-rda ordination
##and not the relationship of FDis to the CWM-RDA axes

